===============
multivolumefile
===============

MultiVolumefile is a python library to provide a file-object wrapping multiple files
as virtually like as a single file.

Install
=======


```
pip install multivolumefile
```

Contribution
============

You are welcome to contribute the project, as usual on github projects,
Pull-Request are welcome.

License
=======

Multivolume is licensed under GNU Lesser General Public license version 2.1 or later.
